@@ -11,7 +11,6 @@
 
 #include <KPluginFactory>
 #include <KPluginMetaData>
-#include <KPluginLoader>
 
 Palapeli::PuzzleComponent* Palapeli::CreationContextComponent::cast(Type type) const
 {
@@ -33,7 +32,7 @@ Palapeli::PuzzleComponent* Palapeli::CreationContextComponent::cast(Type type) c
 		//TODO: move slicer instantiation to a location that is shared between
 		//      puzzle creator dialog and this function
 		//find slicer
-        const QVector<KPluginMetaData> offers = KPluginMetaData::findPlugins(QStringLiteral("palapelislicers"), [cc](const KPluginMetaData &m) {
+        const QList<KPluginMetaData> offers = KPluginMetaData::findPlugins(QStringLiteral("palapelislicers"), [cc](const KPluginMetaData &m) {
             return m.pluginId() == cc.slicer;
         });
 		if (offers.isEmpty())
@@ -42,7 +41,7 @@ Palapeli::PuzzleComponent* Palapeli::CreationContextComponent::cast(Type type) c
 			return nullptr;
 		}
 		//initialize requested slicer plugin
-        QScopedPointer<Pala::Slicer> slicer;
+        std::unique_ptr<Pala::Slicer> slicer;
         if (auto plugin = KPluginFactory::instantiatePlugin<Pala::Slicer>(offers.first(), nullptr).plugin) {
             slicer.reset(plugin);
         } else {
